
# Slot: has population context


a biological population (general, study, cohort, etc.) with a specific set of characteristics to constrain an association.

URI: [biolink:has_population_context](https://w3id.org/biolink/vocab/has_population_context)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [ExposureEventToOutcomeAssociation](ExposureEventToOutcomeAssociation.md)
